@@ -10,16 +10,44 @@
 #include "../GIOP/giop-debug.h"
 
 void
-ORBit_ObjectAdaptor_set_thread_hint (ORBit_ObjectAdaptor adaptor,
-				     ORBitThreadHint     thread_hint)
+ORBit_ObjectAdaptor_set_thread_hintv (ORBit_ObjectAdaptor adaptor,
+				      ORBitThreadHint     thread_hint,
+				      va_list             args)
 {
 	g_return_if_fail (adaptor != NULL);
 	g_return_if_fail (thread_hint >= ORBIT_THREAD_HINT_NONE &&
 			  thread_hint <= ORBIT_THREAD_HINT_ALL_AT_IDLE);
 
 	adaptor->thread_hint = thread_hint;
+	switch (thread_hint) {
+	case ORBIT_THREAD_HINT_PER_OBJECT:
+	case ORBIT_THREAD_HINT_PER_REQUEST:
+	case ORBIT_THREAD_HINT_PER_POA:
+	case ORBIT_THREAD_HINT_PER_CONNECTION:
+	case ORBIT_THREAD_HINT_ON_CONTEXT:
+		if (link_thread_safe ())
+			link_set_io_thread (TRUE);
+		break;
+	case ORBIT_THREAD_HINT_NONE:
+	case ORBIT_THREAD_HINT_ONEWAY_AT_IDLE:
+	case ORBIT_THREAD_HINT_ALL_AT_IDLE:
+		break;
+	}
 }
 
+void
+ORBit_ObjectAdaptor_set_thread_hint (ORBit_ObjectAdaptor adaptor,
+				     ORBitThreadHint     thread_hint,
+				     ...)
+{
+	va_list args;
+
+	va_start (args, thread_hint);
+	ORBit_ObjectAdaptor_set_thread_hintv (adaptor, thread_hint, args);
+	va_end (args);
+}
+
+
 ORBitThreadHint
 ORBit_ObjectAdaptor_get_thread_hint (ORBit_ObjectAdaptor adaptor)
 {
@@ -35,14 +63,14 @@ ORBit_adaptor_setup (ORBit_ObjectAdaptor adaptor,
 	int adaptor_id;
 	CORBA_long *tptr;
 
-	LINC_MUTEX_LOCK (ORBit_RootObject_lifecycle_lock);
+	LINK_MUTEX_LOCK (ORBit_RootObject_lifecycle_lock);
 	{
 		adaptor_id = orb->adaptors->len;
 
 		g_ptr_array_set_size (orb->adaptors, adaptor_id + 1);
 		g_ptr_array_index    (orb->adaptors, adaptor_id) = adaptor;
 	}
-	LINC_MUTEX_UNLOCK (ORBit_RootObject_lifecycle_lock);
+	LINK_MUTEX_UNLOCK (ORBit_RootObject_lifecycle_lock);
 
 	adaptor->thread_hint = ORBIT_THREAD_HINT_NONE;
 
@@ -77,7 +105,7 @@ ORBit_adaptor_find (CORBA_ORB orb, ORBit_ObjectKey *objkey)
 	if (adaptorId < 0 || adaptorId >= orb->adaptors->len)
 		return NULL;
 
-	LINC_MUTEX_LOCK (ORBit_RootObject_lifecycle_lock);
+	LINK_MUTEX_LOCK (ORBit_RootObject_lifecycle_lock);
 	{
 		adaptor = g_ptr_array_index (orb->adaptors, adaptorId);
 
@@ -88,7 +116,7 @@ ORBit_adaptor_find (CORBA_ORB orb, ORBit_ObjectKey *objkey)
 		else
 			ORBit_RootObject_duplicate_T (adaptor);
 	}
-	LINC_MUTEX_UNLOCK (ORBit_RootObject_lifecycle_lock);
+	LINK_MUTEX_UNLOCK (ORBit_RootObject_lifecycle_lock);
 
 	return adaptor;
 }
